==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OdpisZwrot.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.TypZwrotu;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class OdpisZwrot extends GenericDPSObject {
    /**
     * ODPIS_ZWROT.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ODPIS_ZWROT.NIEOBECNOSC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long nieobecnoscId;

    /**
     * ODPIS_ZWROT.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * ODPIS_ZWROT.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypZwrotu typ;

    /**
     * ODPIS_ZWROT.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zadluzeniePozycjaId;

    /**
     * ODPIS_ZWROT.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * ODPIS_ZWROT.ODPIS_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long odpisId;

    /**
     * ODPIS_ZWROT.DATA_KSIEGOWANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataKsiegowania;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ODPIS_ZWROT.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ODPIS_ZWROT.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ODPIS_ZWROT.NIEOBECNOSC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getNieobecnoscId() {
        return nieobecnoscId;
    }

    /**
     * ODPIS_ZWROT.NIEOBECNOSC_ID
     *
     * @param nieobecnoscId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNieobecnoscId(Long nieobecnoscId) {
        this.nieobecnoscId = nieobecnoscId;
    }

    /**
     * @return ODPIS_ZWROT.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * ODPIS_ZWROT.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return ODPIS_ZWROT.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypZwrotu getTyp() {
        return typ;
    }

    /**
     * ODPIS_ZWROT.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypZwrotu typ) {
        this.typ = typ;
    }

    /**
     * @return ODPIS_ZWROT.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * ODPIS_ZWROT.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @return ODPIS_ZWROT.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * ODPIS_ZWROT.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return ODPIS_ZWROT.ODPIS_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOdpisId() {
        return odpisId;
    }

    /**
     * ODPIS_ZWROT.ODPIS_ID
     *
     * @param odpisId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOdpisId(Long odpisId) {
        this.odpisId = odpisId;
    }

    /**
     * @return ODPIS_ZWROT.DATA_KSIEGOWANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataKsiegowania() {
        return dataKsiegowania;
    }

    /**
     * ODPIS_ZWROT.DATA_KSIEGOWANIA
     *
     * @param dataKsiegowania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataKsiegowania(Date dataKsiegowania) {
        this.dataKsiegowania = dataKsiegowania;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OdpisZwrot other = (OdpisZwrot) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getNieobecnoscId() == null ? other.getNieobecnoscId() == null : this.getNieobecnoscId().equals(other.getNieobecnoscId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getOdpisId() == null ? other.getOdpisId() == null : this.getOdpisId().equals(other.getOdpisId()))
            && (this.getDataKsiegowania() == null ? other.getDataKsiegowania() == null : this.getDataKsiegowania().equals(other.getDataKsiegowania()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getNieobecnoscId() == null) ? 0 : getNieobecnoscId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getOdpisId() == null) ? 0 : getOdpisId().hashCode());
        result = prime * result + ((getDataKsiegowania() == null) ? 0 : getDataKsiegowania().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", nieobecnoscId=").append(nieobecnoscId);
        sb.append(", kwota=").append(kwota);
        sb.append(", typ=").append(typ);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append(", data=").append(data);
        sb.append(", odpisId=").append(odpisId);
        sb.append(", dataKsiegowania=").append(dataKsiegowania);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OdpisZwrot.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.TypZwrotu;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class OdpisZwrot extends GenericDPSObject {
    /**
     * ODPIS_ZWROT.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ODPIS_ZWROT.NIEOBECNOSC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long nieobecnoscId;

    /**
     * ODPIS_ZWROT.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * ODPIS_ZWROT.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypZwrotu typ;

    /**
     * ODPIS_ZWROT.ZADLUZENIE_POZYCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zadluzeniePozycjaId;

    /**
     * ODPIS_ZWROT.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * ODPIS_ZWROT.ODPIS_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long odpisId;

    /**
     * ODPIS_ZWROT.DATA_KSIEGOWANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataKsiegowania;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ODPIS_ZWROT.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ODPIS_ZWROT.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ODPIS_ZWROT.NIEOBECNOSC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getNieobecnoscId() {
        return nieobecnoscId;
    }

    /**
     * ODPIS_ZWROT.NIEOBECNOSC_ID
     *
     * @param nieobecnoscId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNieobecnoscId(Long nieobecnoscId) {
        this.nieobecnoscId = nieobecnoscId;
    }

    /**
     * @return ODPIS_ZWROT.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * ODPIS_ZWROT.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return ODPIS_ZWROT.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypZwrotu getTyp() {
        return typ;
    }

    /**
     * ODPIS_ZWROT.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypZwrotu typ) {
        this.typ = typ;
    }

    /**
     * @return ODPIS_ZWROT.ZADLUZENIE_POZYCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZadluzeniePozycjaId() {
        return zadluzeniePozycjaId;
    }

    /**
     * ODPIS_ZWROT.ZADLUZENIE_POZYCJA_ID
     *
     * @param zadluzeniePozycjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZadluzeniePozycjaId(Long zadluzeniePozycjaId) {
        this.zadluzeniePozycjaId = zadluzeniePozycjaId;
    }

    /**
     * @return ODPIS_ZWROT.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * ODPIS_ZWROT.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return ODPIS_ZWROT.ODPIS_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOdpisId() {
        return odpisId;
    }

    /**
     * ODPIS_ZWROT.ODPIS_ID
     *
     * @param odpisId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOdpisId(Long odpisId) {
        this.odpisId = odpisId;
    }

    /**
     * @return ODPIS_ZWROT.DATA_KSIEGOWANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataKsiegowania() {
        return dataKsiegowania;
    }

    /**
     * ODPIS_ZWROT.DATA_KSIEGOWANIA
     *
     * @param dataKsiegowania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataKsiegowania(Date dataKsiegowania) {
        this.dataKsiegowania = dataKsiegowania;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OdpisZwrot other = (OdpisZwrot) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getNieobecnoscId() == null ? other.getNieobecnoscId() == null : this.getNieobecnoscId().equals(other.getNieobecnoscId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getZadluzeniePozycjaId() == null ? other.getZadluzeniePozycjaId() == null : this.getZadluzeniePozycjaId().equals(other.getZadluzeniePozycjaId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getOdpisId() == null ? other.getOdpisId() == null : this.getOdpisId().equals(other.getOdpisId()))
            && (this.getDataKsiegowania() == null ? other.getDataKsiegowania() == null : this.getDataKsiegowania().equals(other.getDataKsiegowania()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getNieobecnoscId() == null) ? 0 : getNieobecnoscId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getZadluzeniePozycjaId() == null) ? 0 : getZadluzeniePozycjaId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getOdpisId() == null) ? 0 : getOdpisId().hashCode());
        result = prime * result + ((getDataKsiegowania() == null) ? 0 : getDataKsiegowania().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", nieobecnoscId=").append(nieobecnoscId);
        sb.append(", kwota=").append(kwota);
        sb.append(", typ=").append(typ);
        sb.append(", zadluzeniePozycjaId=").append(zadluzeniePozycjaId);
        sb.append(", data=").append(data);
        sb.append(", odpisId=").append(odpisId);
        sb.append(", dataKsiegowania=").append(dataKsiegowania);
        sb.append("]");
        return sb.toString();
    }
}
